@@ -1,3 +1,4 @@
+from entropylab.components.lab_topology import ExperimentResources, LabResources
 from entropylab.pipeline.api.data_reader import ExperimentReader
 from entropylab.pipeline.api.data_writer import RawResultData
 from entropylab.pipeline.api.execution import EntropyContext
@@ -8,11 +9,10 @@ from entropylab.pipeline.graph_experiment import (
     SubGraphNode,
     pynode,
 )
-from entropylab.components.lab_topology import ExperimentResources, LabResources
+from entropylab.pipeline.params.param_store import ParamStore
 from entropylab.pipeline.results_backend.sqlalchemy.db import SqlAlchemyDB
 from entropylab.pipeline.script_experiment import Script, script_experiment
-from entropylab.pipeline.api.in_process_param_store import InProcessParamStore
-from entropylab.quam.core import QuAMManager, QuAM
+from entropylab.quam.core import QuAMManager
 
 __all__ = [
     "ExperimentReader",
@@ -28,7 +28,6 @@ __all__ = [
     "SqlAlchemyDB",
     "Script",
     "script_experiment",
-    "InProcessParamStore",
-    "QuAM",
+    "ParamStore",
     "QuAMManager",
 ]
